@@ -1,4 +1,4 @@
 from .code_speed_test import speed_test
 from . import session
-from .result import ActionStatus, Result
+from .result import Result
 
