@@ -4,7 +4,10 @@ from sqlalchemy.orm import Session
 
 class SessionManager:
     """
-    Session Manager
+    Factory class intended for session control.
+    Example of usage:
+    def get_session_manager():
+        return SessionManager(SessionMaker)
     """
     def __init__(self, session_factory):
         self._current_session = None
